@@ -17,6 +17,16 @@ expect_equal(
     take(mtcars, total = .N, by =.(am, vs))
 )
 
+expect_equal(
+    dt_count(mtcars, "^(am|vs)", name = "total"),
+    take(mtcars, total = .N, by =.(vs, am))
+)
+
+expect_equal(
+    dt_count(mtcars, vs %to% gear, name = "total"),
+    take(mtcars, total = .N, by =.(vs, am, gear))
+)
+
 expect_equal(
     dt_count(mtcars, am, vs, sort = TRUE, name = "total"),
     take(mtcars, total = .N, by =.(am, vs)) %>% sort_by(-total)
@@ -108,8 +118,30 @@ expect_equal(
     query_if(mtcars, order(-mpg), head(.SD, 2), by = list(am, vs))
 )
 
+indirect = c('am', 'vs')
+expect_equal(
+    dt_top_n(mtcars, 2, order_by = mpg, by = cols("{indirect}")),
+    query_if(mtcars, order(-mpg), head(.SD, 2), by = list(am, vs))
+)
 
 expect_equal(
     dt_top_n(mtcars, -2, order_by = mpg, by = list(am, vs)),
     query_if(mtcars, order(-mpg), tail(.SD, 2), by = list(am, vs))
 )
+
+
+cat("\nContext:","copy", "\n")
+
+expect_identical(
+    copy(), maditr::copy
+)
+
+data(iris)
+expect_identical(
+    copy(iris), iris
+)
+
+
+expect_identical(
+    copy(1), 1
+)
